Encoding: UTF-8
Package: CADF
Title: Customer Analytics Data Formatting
Version: 0.1
Description: Converts customer transaction data (ID, purchase date) into a R6 class called customer.  The class stores various customer analytics calculations at the customer level. The package also contains functionality to convert data in the R6 class to data.frames that can serve as inputs for various customer analytics models.
License: GPL-3
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.1
Imports: R6
Suggests: knitr, rmarkdown, lubridate, markovchain, utils, survival
VignetteBuilder: knitr
Authors@R: 
  person("Ludwig", "Steven", email = "steven.ludwig@u.northwestern.edu",
    role = c("aut", "cre"))
Maintainer: Ludwig Steven <steven.ludwig@u.northwestern.edu>
NeedsCompilation: no
Packaged: 2024-10-28 23:36:43 UTC; steve
Author: Ludwig Steven [aut, cre]
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2024-10-31 14:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 17:20:08 UTC; unix
